0.9.9 API documentation: random.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
random.hpp File Reference

GLM_GTC_random More...

Go to the source code of this file.

## Functions
template<typename T >
GLM_FUNC_DECL vec< 3, T, defaultp > | ballRand (T Radius)
| Generate a random 3D vector which coordinates are regulary distributed within the volume of a ball of a given radius. More...
template<typename T >
GLM_FUNC_DECL vec< 2, T, defaultp > | circularRand (T Radius)
| Generate a random 2D vector which coordinates are regulary distributed on a circle of a given radius. More...
template<typename T >
GLM_FUNC_DECL vec< 2, T, defaultp > | diskRand (T Radius)
| Generate a random 2D vector which coordinates are regulary distributed within the area of a disk of a given radius. More...
template<typename genType >
GLM_FUNC_DECL genType | gaussRand (genType Mean, genType Deviation)
| Generate random numbers in the interval [Min, Max], according a gaussian distribution. More...
template<typename genType >
GLM_FUNC_DECL genType | linearRand (genType Min, genType Max)
| Generate random numbers in the interval [Min, Max], according a linear distribution. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | linearRand (vec< L, T, Q > const &Min, vec< L, T, Q > const &Max)
| Generate random numbers in the interval [Min, Max], according a linear distribution. More...
template<typename T >
GLM_FUNC_DECL vec< 3, T, defaultp > | sphericalRand (T Radius)
| Generate a random 3D vector which coordinates are regulary distributed on a sphere of a given radius. More...

## Detailed Description

GLM_GTC_random

See also
  Core features (dependence)
  gtx_random (extended)

Definition in file random.hpp.